Learn R Programming

penDvine (version 0.2.2)

penDvine-package: The package 'penDvine' offers routines for estimating densities and copula distribution of D-vines.

Description

The package 'penDvine' offers routines for estimating densities and distribution of D-vines. For details see the description of the function Dvine().

Arguments

Details

ll{ Package: penDvine Type: Package Version: 0.2.2 Date: 2013-02-07 License: GPL (>= 2) LazyLoad: yes } The packages contributes the function 'Dvine()' for estimating densities and distributions of Dvines using penalized splines techniques.

References

Flexible Pair-Copula Estimation in D-vines using Bivariate Penalized Splines, Kauermann G. and Schellhase C. (2013), (to appear).

Examples

Run this code
#This examples describes the estimation of a D-vine to winddata,
#available in this package. After the margins are prepared, we estimate a
#D-vine using B-splines with 9 (K+1) marginal knots and penalizing second (m=2)
#order differences (pen=1) of the basis coefficients.

  #data(Winddata)
  #print(dim(Winddata))
  #bspl.diff2 <-  Dvine(Winddata,K=8,pen=1,lambda=100,order.Dvine=FALSE,base="B-spline",m=2)

Run the code above in your browser using DataLab